@@ -1,4 +1,4 @@
-Turnover <-function(matrix ,method="r1" ,sims=1000 ,scores=1, order=TRUE){
+Turnover <-function(matrix ,method="r1" ,sims=1000 ,scores=1, order=TRUE, allow.empty=FALSE){
 	require(vegan)
 
 if(order==TRUE){matrix=OrderMatrix(matrix,scores=scores)}
@@ -26,7 +26,7 @@ turnover=function(web){
 }
 
 	statistic=turnover(matrix)
-	nulls=nullmaker(matrix=matrix, sims=sims, method=method)
+	nulls=nullmaker(matrix=matrix, sims=sims, method=method,allow.empty=allow.empty)
 	simstat=as.numeric(lapply(nulls,turnover))
 	varstat=sd(simstat)
 	z = (mean(simstat)-statistic)/(varstat)
